@@ -1,4 +1,5 @@
 """Configuration parsing"""
+
 from configparser import ConfigParser
 from pathlib import Path
 
@@ -20,15 +21,15 @@ def parse_config(config_file):
     """
 
     config = ConfigParser()
-    with open(config_file, 'r') as f:
+    with open(config_file, "r") as f:
         config.read_file(f)
 
-    project = config['metadata']['name']
-    copyright = config['metadata'].get('copyright', 'NO COPYRIGHT')
-    author = config['metadata'].get('author', 'NO AUTHOR')
+    project = config["metadata"]["name"]
+    copyright = config["metadata"].get("copyright", "NO COPYRIGHT")
+    author = config["metadata"].get("author", "NO AUTHOR")
 
     # The full version, including alpha/beta/rc tags
-    release = config['metadata'].get('version', 'NO VERSION')
-    display_name = config['metadata'].get('display_name', config['metadata']['name'])
+    release = config["metadata"].get("version", "NO VERSION")
+    display_name = config["metadata"].get("display_name", config["metadata"]["name"])
 
     return project, copyright, author, release, display_name
